/*******************************************************************************
 * Copyright (c) 2007, 2011 THALES GLOBAL SERVICES.
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *    Obeo - initial API and implementation
 *******************************************************************************/
package org.eclipse.sirius.business.internal.repair.commands;

import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.emf.common.command.IdentityCommand;
import org.eclipse.sirius.business.api.repair.IRepairParticipant;
import org.eclipse.sirius.viewpoint.DView;

/**
 * SaveModelElementStateRecordingCommand.
 * 
 * @author esteban
 */
public class SaveModelElementStateCommand extends IdentityCommand {

    private IRepairParticipant participant;

    private DView view;

    private IProgressMonitor monitor;

    /**
     * Default constructor.
     * 
     * @param participant
     *            {@link IRepairParticipant}
     * @param view
     *            {@link DView}
     * @param monitor
     *            {@link IProgressMonitor}
     */
    public SaveModelElementStateCommand(IRepairParticipant participant, DView view, IProgressMonitor monitor) {
        super();
        this.participant = participant;
        this.view = view;
        this.monitor = monitor;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void execute() {
        participant.saveModelElementState(view, monitor);
        participant = null;
        view = null;
    }

    /**
     * Overridden to avoid the CommandStack to keep a reference to this command.
     * 
     * {@inheritDoc}
     */
    @Override
    public boolean canUndo() {
        return false;
    }
}
